@@ -65,7 +65,7 @@
 #' @return A dataframe with the financial data for working days, when markets
 #' are open. All price data is \strong{measured} at the unit of the financial
 #' exchange. For example, price
-#' data for FB (NYSE/US) is measures in dollars, while price data for
+#' data for META (NYSE/US) is measures in dollars, while price data for
 #' PETR3.SA (B3/BR) is measured in Reais (Brazilian currency).
 #'
 #' The return dataframe contains the following columns:
@@ -187,6 +187,9 @@ yf_get <- function(tickers,
     }
   }
 
+  # sort tickers (makes sure acum ret is correct)
+  tickers <- sort(tickers)
+
   # check threshold
   if ((thresh_bad_data < 0) | (thresh_bad_data > 1)) {
     stop("Input thresh_bad_data should be a proportion between 0 and 1")
